==> quantlib-0.3.0.tbz: include/ql/Calendars/london.hpp <==


/*
 Copyright (C) 2000, 2001, 2002 RiskMap srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it under the
 terms of the QuantLib license.  You should have received a copy of the
 license along with this program; if not, please email ferdinando@ametrano.net
 The license is also available online at http://quantlib.org/html/license.html

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/
/*! \file london.hpp
    \brief London calendar

    \fullpath
    ql/Calendars/%london.hpp
*/

// $Id: london.hpp,v 1.9 2002/01/16 14:43:48 nando Exp $

#ifndef quantlib_london_calendar_h
#define quantlib_london_calendar_h

#include <ql/calendar.hpp>

namespace QuantLib {

    namespace Calendars {

        //! %London calendar
        /*! Holidays:
            <ul>
            <li>Saturdays</li>
            <li>Sundays</li>
            <li>New Year's Day, January 1st (possibly moved to Monday)</li>
            <li>Good Friday</li>
            <li>Easter Monday</li>
            <li>Bank Holiday, first Monday of May</li>
            <li>Bank Holiday, last Monday of May</li>
            <li>Bank Holiday, last Monday of August</li>
            <li>Christmas, December 25th (possibly moved to Monday or
                Tuesday)</li>
            <li>Boxing Day, December 26th (possibly moved to Monday or
                Tuesday)</li>
            </ul>
        */
        class London : public Calendar {
          private:
            class LonCalendarImpl : public Calendar::WesternCalendarImpl {
              public:
                std::string name() const { return "London"; }
                bool isBusinessDay(const Date&) const;
            };
          public:
            London()
            : Calendar(Handle<CalendarImpl>(new LonCalendarImpl)) {}
            //! returns a factory of %London calendars
        };

    }

}


#endif

==> quantlib-0.3.1.tbz: include/ql/Calendars/london.hpp <==

/*
 Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it under the
 terms of the QuantLib license.  You should have received a copy of the
 license along with this program; if not, please email ferdinando@ametrano.net
 The license is also available online at http://quantlib.org/html/license.html

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file london.hpp
    \brief London calendar

    \fullpath
    ql/Calendars/%london.hpp
*/

// $Id: london.hpp,v 1.10.8.2 2002/12/31 18:40:31 nando Exp $

#ifndef quantlib_london_calendar_h
#define quantlib_london_calendar_h

#include <ql/calendar.hpp>

namespace QuantLib {

    namespace Calendars {

        //! %London calendar
        /*! Holidays:
            <ul>
            <li>Saturdays</li>
            <li>Sundays</li>
            <li>New Year's Day, January 1st (possibly moved to Monday)</li>
            <li>Good Friday</li>
            <li>Easter Monday</li>
            <li>Early May Bank Holiday, first Monday of May</li>
            <li>Spring Bank Holiday, last Monday of May</li>
            <li>Summer Bank Holiday, last Monday of August</li>
            <li>Christmas, December 25th (possibly moved to Monday or
                Tuesday)</li>
            <li>Boxing Day, December 26th (possibly moved to Monday or
                Tuesday)</li>
            </ul>
        */
        class London : public Calendar {
          private:
            class Impl : public Calendar::WesternImpl {
              public:
                std::string name() const { return "London"; }
                bool isBusinessDay(const Date&) const;
            };
          public:
            London()
            : Calendar(Handle<Calendar::Impl>(new London::Impl)) {}
        };

    }

}


#endif
